@@ -32,15 +32,17 @@ def main() -> None:
 
     exclude_ids: List[str] = db.get_work_ids()
     if len(exclude_ids) > 0:
-        print(len(exclude_ids), 'ids was committed work ids to existed db!')
+        print(len(exclude_ids), 'ids was committed to existed db!')
 
     parsed_data: DojinDict = {
         'dlsite': []
         # 'dmm': []
     }
     for site in parsed_data.keys():
+        print('site:', site)
         p = Parser(site, exclude_ids)
         targets = get_filepaths(site)
+        print(len(targets), 'lists of works is found!')
         for page_idx, path in enumerate(targets):
             print('\33[2K\r\033[31mNow: {}\033[0m'.format(path))
             d = p.parse(path, page_idx)
@@ -49,6 +51,8 @@ def main() -> None:
             db.push(parsed_data['dlsite'])
             parsed_data['dlsite'] = []
 
+        print('DONE:', site)
+
 
 if __name__ == '__main__':
     main()
